<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>تنزيل عادي</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>الحصول على القائمة</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>أدخل الرابط:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>تنزيل</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>الخيارات</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>إغلاق</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>رمز المحتوى الرقمي</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>الامتداد</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>الدقة</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>ملاحظة</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>اسم الأداة</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>لصق من الحافظة</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>استُخدمت مؤخراً</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>تعيين خيارات التنزيل</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>تنزيل متعدد</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>الصورة المصغرة</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>الرابط المستخدم للتنزيل</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>لصق رابط من الحافظة</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>رصد وجود رابط في الحافظة</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>أضف الرابط إلى القائمة</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>تعيين</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>تنزيل قائمة تشغيل</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>خيارات التنزيل:</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>وقت بداية الفترة الزمنية(ث:د:س):</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>وقت نهاية الفترة الزمنية(ث:د:س):</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>الفصول (مفصولة بفاصلة):</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>تقسيم حسب الفصول</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>إخفاء</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>رابط قائمة التشغيل</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>مسح ملف الأرشيف الداخلي</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>استخدم ملف أرشيف داخلي</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>المكتبة</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>السابق</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>تحديث</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>فتح مجلد</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>الرئيسية</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>ضبط الإعدادات</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>الإعدادات العامة</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>إظهار أيقونة في شريط المهام</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>الحفظ التلقائي لقائمة الوسائط التي لم يتم تنزيلها</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation>إخفاء التنزيلات تلقائيًا عند اكتمالها</translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>إعادة تعيين الخيار إلى الوضع الافتراضي</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>إسترجاع الخيارات الافتراضية</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>خيارات مُعدة مسبقًا</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>مسار التنزيلات</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>اختر اللغة</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation>إعداد الخادم الوكيل يدوياً</translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation>الحصول على إعدادات الخادم الوكيل من بيئة التشغيل</translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation>بدون استخدام خادم وكيل</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>الخيارات المبدئية للأداة</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>حجم الملف</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>&gt;الحصول على قائمة الخيارات</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>الاشتراكات</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>وصف المحتوى الرقمي</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>أضف</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>الرابط</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>تم</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>تفعيل تبويب المكتبة</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation>الحد الأقصى للتنزيلات المتزامنة</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>ترميز النص</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation>عرض معلومات الإصدار الحالي وتنزيل التحديثات تلقائيًا</translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation>عرض معلومات الإصدار الحالي و الإصدار الأخير</translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation>عرض معلومات الإصدار فقط</translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation>عدم فعل اي شيء</translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation>الإجراءات عند بدء التشغيل</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>الموقع</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>اسم الأداة</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>الافتراضي</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>خيارات للإضافة</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>إدارة الروابط</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>خيارات التنزيل</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>تخصيص أي رابط يجب أن تتعامل معه أداة معينة</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>مرشح الرابط</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation>إعدادات الخادم الوكيل</translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation>استخدام إعدادات النظام للخادم الوكيل</translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation>إعداد الخادم الوكيل يدوياً
مثال 1: 192.168.93.89:8080
مثال 2: ${gateway}:8080</translation>
    </message>
    <message>
        <source>About</source>
        <translation>معلومات</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation>تشغيل الوسائط التي تم تنزيلها</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>إعادة تسمية</translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation>أدخل رابط قائمة التشغيل. لإضافة قوائم تشغيل متعددة، افصل بينها بمسافة أو سطر جديد</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>إعادة تسمية الملف إلى النص أدناه</translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation>زر لفتح المجلد الذي سيستخدم كمجلد للتنزيلات</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation>زر لفتح المجلد الذي يحتوي على ملفات تكوين السمة</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation>زر لفتح المجلد الذي يحتوي على الامتدادات والملفات التنفيذية.</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation>هل أنت متأكد من رغبتك في إعادة تعيين هذه الخيارات إلى قيمها الافتراضية؟</translation>
    </message>
    <message>
        <source>No</source>
        <translation>لا</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>نعم</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 Preset Options</source>
        <translation>خيارات مُعدة مسبقًا لـ %1</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>اسم الملف بامتداد &quot;.txt&quot; سيحفظ الروابط فقط</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation>إخفاء الصف</translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation>إظهار كل الصفوف المخفية</translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation>فشل تشغيل الملف القابل للتنفيذ %1</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>نسخ الرابط</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation>فتح الرابط باستخدام %1</translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation>نسخ الرابط %1</translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>حفظ القائمة في ملف</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>التاريخ</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>الردود على</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>حفظ الترجمة إلى ملف</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>اسم الأداة:</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>الحصول على قائمة من ملف</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>خيارات مُعدة مسبقًا</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>مسح</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>فتح مجلد التنزيلات</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>الإصدار</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation>صفحة المشروع</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>حقوق الطبع والنشر</translation>
    </message>
    <message>
        <source>License</source>
        <translation>الترخيص</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>البريد الإلكتروني</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>إصدار Qt</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>هذا البرنامج هو برنامج مجاني؛ يمكنك إعادة توزيعه و/أو تعديله بموجب شروط رخصة جنو العمومية التي نشرتها مؤسسة البرمجيات الحرة؛ إما الإصدار 2 من الرخصة، أو (حسب اختيارك) أي إصدار لاحق.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>يتم توزيع هذا البرنامج على أمل أن يكون مفيداً، ولكن دون أي ضمانات؛ دون حتى الضمان المضمر لقابلية التسويق أو الملاءمة لغرض معين. راجع رخصة جنو العمومية للمزيد من التفاصيل.</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>البولندية (بولندا)</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>الإنجليزية (الولايات المتحدة الأمريكية)</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>الإسبانية (إسبانيا)</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>الصينية (الصين)</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>التركية (تركيا)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>الروسية (روسيا)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>اليابانية (اليابان)</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>الفرنسية (فرنسا)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>الإيطالية (إيطاليا)</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>السويدية (السويد)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>الألمانية (ألمانيا)</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>البرتغالية (البرازيل)</translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation>الهولندية (هولندا)</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>خطأ، تعذّر العثور على الملف القابل للتنفيذ لل الواجهة الخلفية &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>الأداة &quot;%1&quot; تتطلب على الأقل الإصدار &quot;%2&quot; من برنامج تنزيل الوسائط</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>لتعطيل عمليات التحقق هذه، قم بما يلي:-</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. اذهب إلى علامة التبويب &quot;ضبط الإعدادات&quot;.</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. اذهب إلى علامة التبويب الفرعية &quot;الإعدادات العامة&quot;.</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation>3. اضغط على قائمة &quot;الإجراءات عند بدء التشغيل&quot;.</translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation>4. اختر &quot;عدم فعل اي شيء&quot;.</translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation>التشغيل في الوضع المحمول</translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation>التشغيل في وضع التثبيت</translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation>مسار التنزيلات: %1</translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation>مسار App Data: %1</translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation>تعيين عنوان الخادم الوكيل لـ %1</translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation>إلغاء تعيين عنوان الخادم الوكيل</translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>خطأ، فشل في تحليل ملف الإعداد &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>فشل في تحميل أداة إضافية</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>فشل في العثور على الملف القابل للتنفيذ &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>فشل في العثور على python3 القابل للتنفيذ للواجهة الخلفية &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>حدث خلل في الشبكة</translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation>الرابط غير مدعوم</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>تم إلغاء التنزيل</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>رمز الخطأ</translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation>فشل التنزيل، الأداة واجهت مشكلة بالتشغيل</translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>فشل التنزيل، حدث عطل بالأداة</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>رمز المحتوى الرقمي</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>الامتداد</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>الدقة</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>الحجم</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>ملاحظة</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>فشل في فتح الملف للكتابة</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>فشل في فتح الملف للقراءة</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>الوقت المنقضي:</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>فشل في العثور على معلومات الإصدار، تأكد من تثبيت &quot;%1&quot; %1&quot; وأنه يعمل بشكل صحيح</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>الإصدار الذي تم العثور عليه</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation>فشل في فتح المسار للكتابة: %1</translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>فشل في الاستخراج</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>فشلت الشبكة في الاستجابة خلال %1 ثانية</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>فشل التنزيل، تعذر إنشاء المسار التالي: </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>بدء التنزيل</translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation>فشل في العثور على &quot;bsdtar.exe&quot; قابل للتنفيذ</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>فشل التنزيل</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>فشل في تحليل ملف json من github</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>جارٍ التنزيل</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>الوجهة</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>اكتمل التحديث، أعد التشغيل لاستخدام الإصدار الجديد</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>لم يتم العثور على الملف</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>تم التنزيل</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>استخراج الأرشيف: </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>العملية جارية</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>اكتمل التنزيل</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>إعادة تعيين مجلد التنزيل إلى الافتراضي</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>المعالجة اللاحقة</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>تنزيل</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>فرض التنزيل</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>إظهار نافذة السجل</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>تاريخ الرفع:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>المدة الزمنية:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>اسم الترجمة</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>خيارات التنزيل</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>خيارات تنزيل إضافية</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>تنزيل الفترة الزمنية</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>تنزيل الفصول</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>تقسيم حسب الفصول</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>المحتوى الرقمي موجود بالفعل في الأرشيف</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>داكن</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>الطريقة</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>الوقت المتبقي</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>تم التنزيل</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation>تم تنزيله بالفعل %1</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>قد يستغرق هذا الأمر وقتًا طويلًا</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>السرعة:</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation>يوجد تحديث لـ %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>الإصدار الأحدث هو %1، جارٍ التحديث</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation>التحقق من الإصدار المثبت من %1</translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation>الإصدار الذي تم العثور عليه: %1</translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation>الإصدار الأحدث هو: %1</translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>يُرجى تحديث &quot;%1&quot; إلى الإصدار &quot;%2&quot; على الأقل</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>الصيغة المطلوبة غير متوفرة</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>الرابط المدخل غير صالح</translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation>صوت بأعلى جودة</translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation>صوت بأعلى جودة(MP3)</translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation>فيديو مع صوت بأعلى جودة</translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation>فيديو مع صوت بأعلى جودة وبدقة %1</translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation>تحذير: تخطّي محتوى الحافظة</translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation>عرض المجلدات اولًا</translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation>الترتيب تصاعديًا</translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation>الترتيب حسب التاريخ</translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation>الترتيب حسب الاسم</translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation>الترتيب تنازليًا</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>المرشح</translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation>عدم استخدام مرشح</translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation>استخراج الصوت</translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation>استخراج الصوت بصيغة MP3</translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation>مواقع أخرى</translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation>القناة الآمنة لويندوز</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation>هناك مشكلة، فشل حذف المجلد: %1</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>العربية</translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation>صوت بأعلى جودة+صورة مصغرة</translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation>يوتيوب</translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation>التحديث التلقائي لـ %1 معطل</translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation>الإصدار الأحدث هو %1، التحديث التلقائي معطل</translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation>المؤلف: %1</translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation>عدد مرات الإعجاب: %1</translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation>الكورية (كوريا)</translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation>قم بتسجيل الدخول لإثبات أنك لست روبوتًا</translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation>إخفاء القائمة</translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>تحديد ملف للتنزيل المتعدد</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>فتح</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>جارٍ تنزيل التعليقات</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>تنزيل</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>نسخ الرابط</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>إظهار الترجمات</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>عرض التعليقات</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>عرض خيارات التنزيل</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>تنزيل مقطع مجتزء</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>تعيين</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>جارٍ تنزيل الترجمات</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation>الترتيب حسب التاريخ تصاعديًا</translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation>الترتيب حسب التاريخ تنازليًا</translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation>الترتيب حسب عدد مرات الإعجاب</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>إعادة تسمية</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>تعيين كافتراضي</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>حدد ملف الأداة</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>تعيين مجلد التنزيلات</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>تعديل</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>أضف</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>تعيين القيم الافتراضية</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>حذف الكل</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>إعادة تسمية</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation>هل أنت متأكد من رغبتك في حذف الملف أدناه؟</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation>هل أنت متأكد من رغبتك في حذف المجلد أدناه؟</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>نعم</translation>
    </message>
    <message>
        <source>No</source>
        <translation>لا</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation>هل أنت متأكد من رغبتك في حذف جميع الملفات والمجلدات؟</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>إعادة تسمية الملف إلى النص أدناه</translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation>إعادة تسمية المجلد إلى النص أدناه</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>نافذة السجل</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>إغلاق</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>مسح</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>فتح</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>إخفاء أزرار التحكم</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>الحصول على خيارات القائمة:</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>نسخ الرابط</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>عرض التعليقات</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>عرض كل ما تم تحديثه</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>تنزيل كل ما تم تحديثه</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>إدارة الاشتراكات</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>عدد الصفحات التي تم تنزيلها</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>جارٍ تنزيل معلومات الفيديو</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>إظهار أزرار التحكم</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>إظهار</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>إخفاء</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>قد يستغرق هذا الأمر وقتًا طويلًا</translation>
    </message>
</context>
</TS>
